==> haskell-coinbase-pro-0.9.3.2-146-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-GBXOIDHL3dH9TdyqAQVOeL
key:                  coinbase-pro-0.9.3.2-GBXOIDHL3dH9TdyqAQVOeL
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  3e9096c87059c2558f0d1c7d97a8ece3
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.2.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-GBXOIDHL3dH9TdyqAQVOeL
depends:
    HsOpenSSL-0.11.7.6-GftHmOtGBEO3l50X7Ujkki
    aeson-2.1.2.1-3Y7c2RiVUt62qtHv6r8uDo
    aeson-casing-0.2.0.0-I6FjPmo6skf5Dt3vTTn898
    async-2.2.5-E2Nvh3WkFMk4pawohHisBC base-4.16.4.0 binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptonite-0.30-ALX3fAyHHVJ93H0nGZJayV exceptions-0.10.4
    http-api-data-0.5.1-6UpuEWGTIci1I2cccKaI8R
    http-client-0.7.15-6X9ivt0kcj346DIp3ns3n9
    http-client-tls-0.3.6.3-E9EYV7m6Tn2jBk4HTNMP8
    http-streams-0.8.9.9-ECliFUSSjVJ5Mo0wOnvmk8
    http-types-0.12.3-CEDOqg5UkjrK6aHCjLhy9P
    io-streams-1.5.2.2-GKHjyKuSf6KCFxNUNjaiby
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-GnkgUFaZcoiLS7LTArWHTl
    servant-0.20.1-1RUMLCRkKl79OGvrQaGSfw
    servant-client-0.20-4taa2fEfJDD66P6sqZjxjQ
    servant-client-core-0.20-EOV3qR9aDeXAQvNBfORCNt
    tasty-1.4.3-4P9niUw2HXJLAdSnzQ3qYx
    tasty-hunit-0.10.1-AdkYJlUZpuFKq6Uo03fedY text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unagi-streams-0.2.7-HambctJlWnqAe02KttdH8r
    unordered-containers-0.2.20-j2FhYOkivM8IxsBmmgbET
    uuid-1.3.15-DBFj40tgZuU7Q5lpHqsQDc
    vector-0.13.1.0-AXstUsf4rEVFm5YPigldNP
    websockets-0.12.7.3-Kan8ZVVjhWq8b0F0UiTSPJ
    wuss-2.0.1.1-AWmzkFOFC2BElWrVbgECI9

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-coinbase-pro-0.9.3.2-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-BHXLq04WXNp9MXgI7woH4M
key:                  coinbase-pro-0.9.3.2-BHXLq04WXNp9MXgI7woH4M
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  7394f0749ba49619fe00fb5077e024de
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.2.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-BHXLq04WXNp9MXgI7woH4M
depends:
    HsOpenSSL-0.11.7.6-GftHmOtGBEO3l50X7Ujkki
    aeson-2.1.2.1-rSVNuDwxsBHmGlfFvlfkL
    aeson-casing-0.2.0.0-EeQbppW2isBEulm9uuQUtc
    async-2.2.5-E2Nvh3WkFMk4pawohHisBC base-4.16.4.0 binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptonite-0.30-ALX3fAyHHVJ93H0nGZJayV exceptions-0.10.4
    http-api-data-0.5.1-3riIpBhSXcV1qlzhpJm8h8
    http-client-0.7.15-DrtrcNINYMhLFsVui1tUWe
    http-client-tls-0.3.6.3-Cgm4BYTOFwy87jVenAxxdN
    http-streams-0.8.9.9-5LlWf2Fbk5H9RKqr6ZPFKq
    http-types-0.12.3-BiEi4mwYuCYGcSmgAngJ2Y
    io-streams-1.5.2.2-GKHjyKuSf6KCFxNUNjaiby
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-GnkgUFaZcoiLS7LTArWHTl
    servant-0.20.1-AvgCwOtOq195TQ29WKEjYT
    servant-client-0.20-7PfV8bai2s8I13pqSSzjiC
    servant-client-core-0.20-5qzorI6DJpNGCSdV4Gwkr1
    tasty-1.4.3-4P9niUw2HXJLAdSnzQ3qYx
    tasty-hunit-0.10.1-AdkYJlUZpuFKq6Uo03fedY text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unagi-streams-0.2.7-HambctJlWnqAe02KttdH8r
    unordered-containers-0.2.20-1AyI8Q6K7vq4XTDmUndE6S
    uuid-1.3.15-DBFj40tgZuU7Q5lpHqsQDc
    vector-0.13.1.0-AXstUsf4rEVFm5YPigldNP
    websockets-0.12.7.3-Kan8ZVVjhWq8b0F0UiTSPJ
    wuss-2.0.1.1-AWmzkFOFC2BElWrVbgECI9

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
